@@ -1,13 +1,12 @@
 # -*- cperl -*-
 #
-# Copyright (c) 1997-2003 Samuel MOUNIEE
+# Copyright (c) 1997-2006 Samuel MOUNIEE
 #
 #    This file is part of Log::Simple.
 #
 #    Log::Simple is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#    the Free Software Foundation; version 2 of the License.
 #
 #    Log::Simple is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,7 +27,7 @@ use	vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
 
 use	Exporter;
 
-( $VERSION ) = '$Revision: 1.3 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.7 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 
 @ISA		= qw( Exporter );
@@ -142,7 +141,7 @@ log information to STDERR
 =cut
 sub	std_logger {
   my $l  = shift;
-  print STDERR ( $l ) . " : " . join( " + ", @_, "\n" );
+  print STDERR "$l : " . join( " + ", @_, "\n" );
   return $l	unless $CONFESS;
 
   my ( $i, @tmp ) = ( 0 );
@@ -221,14 +220,13 @@ Add tests ...
 
 =head1 COPYRIGHT, LICENCE
 
- Copyright (c) 1997-2002 Samuel MOUNIEE
+ Copyright (c) 1997-2006 Samuel MOUNIEE
 
 This file is part of Log::Simple.
 
 Log::Simple is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+the Free Software Foundation;  version 2 of the License.
 
 Log::Simple is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -242,7 +240,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 =head1 AUTHOR
 
-Samuel Mounie aka Moun's, mouns@cpan.org
+Samuel MouniE<eacute>e aka Moun's, L<mouns@cpan.org>
+
+=head1 MAIN REPOSITORY
+
+L<http://www.mouns.net/devel/CPAN/>
 
 =head1 SEE ALSO
 
